@@ -20,13 +20,16 @@ from copy import copy
 from functools import wraps
 from itertools import count
 from Queue import Empty
-from urlparse import urlparse, unquote
+from urllib import unquote
+from urlparse import urlparse
 try:
     from urlparse import parse_qsl
 except ImportError:  # pragma: no cover
     from cgi import parse_qsl  # noqa
 
-from . import exceptions
+# jython breaks on relative import for .exceptions for some reason
+# (Issue #112)
+from kombu import exceptions
 from .transport import get_transport_cls
 from .utils import kwdict, retry_over_time
 from .utils.compat import OrderedDict, LifoQueue as _LifoQueue
