@@ -4,10 +4,20 @@ kombu.exceptions
 
 Exceptions.
 
-:copyright: (c) 2009 - 2011 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+
+import socket
+
+__all__ = ["NotBoundError", "MessageStateError", "TimeoutError",
+           "LimitExceeded", "ConnectionLimitExceeded",
+           "ChannelLimitExceeded", "StdChannelError", "VersionMismatch",
+           "SerializerNotInstalled"]
+
+TimeoutError = socket.timeout
 
 
 class NotBoundError(Exception):
@@ -20,11 +30,6 @@ class MessageStateError(Exception):
     pass
 
 
-class TimeoutError(Exception):
-    """Operation timed out."""
-    pass
-
-
 class LimitExceeded(Exception):
     """Limit exceeded."""
     pass
@@ -46,3 +51,8 @@ class StdChannelError(Exception):
 
 class VersionMismatch(Exception):
     pass
+
+
+class SerializerNotInstalled(StandardError):
+    """Support for the requested serialization type is not installed"""
+    pass
